<?php
namespace App\Http\Controllers;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Auth;
use Illuminate\Http\Request;
use App\Moperacao;

class MoperacaoController extends Controller
{
    Public Function __construct()
    {
        $this->middleware('auth');
    }

    //******* Lista os dados ********
    public function indexOperacao(Request $request)
    {
        if(!RotaController::Acesso($request->route()->getName()))
        {
            return RotaController::AcessoNegado('home');
        }

        Try
        {
            return view('mineracao.moperacao');
        }
        catch(\Exception $ex)
        {
            return Redirect::back()->withErrors('erro ao carregar os dados: '.$ex->getMessage());
        }
    }

    public function ajaxSalvarOperacao(Request $request)
    {
        //if(!RotaController::Acesso($request->route()->getName())){return RotaController::AcessoNegado('cadastro.operacao');}
        Try
        {
            //$p = Operacao::where(Operacao::$codigo,$request->codigo)->first();
            //if((empty($request->id) && !empty($p)) || (!empty($request->id) && !empty($p) && $request->id != $p->getId()))
            //{
                //return Redirect::route('cadastro.operacao')->withErrors('Já existe um registro com este código.');
            //}

            $descricao  =  strtoupper($request->descricao); 
            $unidade    = Auth::user()->getUnidade();

           /*  id: id, 
            descricao: descricao, 
            data: data, 
            pesoe: pesoe, 
            pesor: pesor, 
            origem: origem, 
            destino: destino, 
            status: status, 
            produto: produto, 
            cliente: cliente
 */

            $operacao = Moperacao::findOrNew($request->id);
            $operacao->setUnidade($unidade);
            $operacao->setDescricao($descricao);
            $operacao->setOrigem($request->origem);
            $operacao->setDestino($request->destino);
            $operacao->setCliente($request->cliente);
            $operacao->setProduto($request->produto);
            $operacao->setData($request->data);
            $operacao->setVol_real($request->pesor);
            $operacao->setVol_estimado($request->pesoe);
            $operacao->setStatus($request->status);
        
            $operacao->save();
            return Redirect::route('mineracao.moperacao');
        }
        catch(\Exception $ex)
        {
            return Redirect::route('mineracao.moperacao')->withErrors('erro ao salvar os dados: '.$ex->getMessage());
        }
    }

    
    
    public function deleteOperacao(Request $request)
    {
        //if(!RotaController::Acesso($request->route()->getName())){return RotaController::AcessoNegado('cadastro.operacao');}

        Try
        {
            if(empty($request->id))
            {
                return Redirect::route('mineracao.moperacao')->withErrors('Código vazio.');
            }

            $operacao = Moperacao::find($request->id);
            $operacao->delete();

            return Redirect::route('mineracao.moperacao');
        }
        catch(\Exception $ex)
        {
            return Redirect::route('mineracao.moperacao')->withErrors('erro ao excluir os dados: '.$ex->getMessage());
        }
    }

    public function ajaxPesquisarOperacao(Request $request)
    {
        try
        {

            //Seleciona dados
            $sql = "SELECT  OPE_id          as id, 
                            date_format(OPE_data,'%d/%m/%Y') as data, 
                            OPE_descricao   as descricao, 
                            OPE_status      as status, 
                            IFNULL(OPE_vol_estimado,'0')    as peso_estimado, 
                            ifnull(OPE_vol_real, '0')       as peso_real, 
                            OPE_FK_CLIE_id  as idcliente, 
                            CLIE_nome       as cliente, 
                            OPE_FK_DEST_id  as iddestino, 
                            DEST_descricao  as destino,
                            OPE_FK_ORI_id   as idorigem, 
                            ORI_descricao   as origem, 
                            OPE_FK_PROD_id  as idproduto, 
                            PROD_descricao  as produto
                    FROM    MIN_operacao, 
                            MIN_destino, 
                            MIN_origem, 
                            SGP_produto, 
                            SGP_cliente
                    WHERE   OPE_FK_CLIE_id  = CLIE_id
                    AND     OPE_FK_DEST_id  = DEST_id
                    AND     OPE_FK_ORI_id   = ORI_id
                    AND     OPE_FK_PROD_id  = PROD_id
                    -- AND OPE_status = 'OP'
                    ORDER BY OPE_data, OPE_descricao;";
                                                     
            //executa a query e guarda o resultado
            $resultado =\DB::select($sql);
            
            $dados = ['consulta'=>$resultado];
            
            return response()->json($dados,200);
        
        }
        catch(\Exception $ex)
        {
            return response()->json('erro ao buscar os dados: '.$ex->getMessage(),500);
        }
    }

    public function ajaxTotalReal(Request $request)
    {
        try
        {

            //Seleciona dados
            $sql = "SELECT  ifnull(SUM(MOV_vol_real),0) as total 
                    FROM    MIN_movimento";
                                                     
            //executa a query e guarda o resultado
            $resultado =\DB::select($sql);
            
            $dados = ['consulta'=>$resultado];
            
            return response()->json($dados,200);
        
        }
        catch(\Exception $ex)
        {
            return response()->json('erro ao buscar os dados: '.$ex->getMessage(),500);
        }
    }


}