<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Auth;
use App\Estadia;
use App\Motorista;
use App\Veiculo;
use App\Mensagem;
use Carbon\Carbon;

class PainelController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }


    public function ajaxPainelChamada(Request $request)
    {
        try
        {
            $fila = Estadia::where(Estadia::$status,'PA')
                            ->whereNotNull(Estadia::$data_chamada)
                            ->whereNull(Estadia::$data_saida)
                            ->get()
                            ->map(function($item)
                            {
                                return
                                [
                                    'id'=>$item->getId(),
                                    'placa'=>$item->Veiculo->getPlaca(),
                                    'motorista'=>$item->Motorista->getNome(),
                                    'destino'=>$item->Destino->getDescricao(),
                                    'cliente'=>$item->Cliente->getNomeFantasia()
                                ];
                            });
            return response()->json($fila,200);
        }
        catch(\Exception $ex)
        {
            return response()->json('erro ao buscar os veículos chamados: ' . $ex->getMessage(),500);
        }
    }
    
    public function indexPainel(Request $request)
    {
        // if(!RotaController::Acesso($request->route()->getName())){return RotaController::AcessoNegado('home');}

        try
        {
            $unid =  Auth::user()->getUnidade();

            $mensagens = Mensagem::where(Mensagem::$ativo,1)->where(Mensagem::$unidade,$unid)->get();
            $now = Carbon::now()->timezone('America/Fortaleza')->format('d/m/Y H:i');
            return View('consulta.painel',['now'=>$now,'mensagens'=>$mensagens]);
        }
        catch(\Exception $ex)
        {
             return Redirect::route('home')->withErrors('Erro ao acessar o painel de chamada: ' . $ex->getMessage());
        }
    }

    public function indexPainelFertgrow(Request $request)
    {
        // if(!RotaController::Acesso($request->route()->getName())){return RotaController::AcessoNegado('home');}

        try
        {
            $unid =  Auth::user()->getUnidade();

            $mensagens = Mensagem::where(Mensagem::$ativo,1)->where(Mensagem::$unidade,$unid)->get();
            $now = Carbon::now()->timezone('America/Fortaleza')->format('d/m/Y H:i');
            return View('consulta.painelfertgrow',['now'=>$now,'mensagens'=>$mensagens]);
        }
        catch(\Exception $ex)
        {
             return Redirect::route('home')->withErrors('Erro ao acessar o painel de chamada: ' . $ex->getMessage());
        }
    }


    public function indexPainelRoma(Request $request)
    {
        // if(!RotaController::Acesso($request->route()->getName())){return RotaController::AcessoNegado('home');}

        try
        {
            $unid =  Auth::user()->getUnidade();
            $mensagens = Mensagem::where(Mensagem::$ativo,1)->where(Mensagem::$unidade,$unid)->get();
            //$mensagens = Mensagem::where(Mensagem::$ativo,1)->get();
            $now = Carbon::now()->timezone('America/Fortaleza')->format('d/m/Y H:i');
            return View('consulta.painelroma',['now'=>$now,'mensagens'=>$mensagens]);
        }
        catch(\Exception $ex)
        {
             return Redirect::route('home')->withErrors('Erro ao acessar o painel de chamada: ' . $ex->getMessage());
        }
    }

        
    public function indexPainelBrasil(Request $request)
    {
        // if(!RotaController::Acesso($request->route()->getName())){return RotaController::AcessoNegado('home');}

        try
        {
            $unid =  Auth::user()->getUnidade();

            $mensagens = Mensagem::where(Mensagem::$ativo,1)->where(Mensagem::$unidade,$unid)->get();
            $now = Carbon::now()->timezone('America/Fortaleza')->format('d/m/Y H:i');
            return View('consulta.painelbrasil',['now'=>$now,'mensagens'=>$mensagens]);
        }
        catch(\Exception $ex)
        {
             return Redirect::route('home')->withErrors('Erro ao acessar o painel de chamada: ' . $ex->getMessage());
        }
    }

    public function indexPainelBrasilFertilizante(Request $request)
    {
        // if(!RotaController::Acesso($request->route()->getName())){return RotaController::AcessoNegado('home');}

        try
        {
            $unid =  Auth::user()->getUnidade();

            $mensagens = Mensagem::where(Mensagem::$ativo,1)->where(Mensagem::$unidade,$unid)->get();
            $now = Carbon::now()->timezone('America/Fortaleza')->format('d/m/Y H:i');
            return View('consulta.painelbrasilfertil',['now'=>$now,'mensagens'=>$mensagens]);
        }
        catch(\Exception $ex)
        {
             return Redirect::route('home')->withErrors('Erro ao acessar o painel de chamada: ' . $ex->getMessage());
        }
    }

    public function ajaxPesquisaObterFila(Request $request)
    {
        try
        {
            $destino = $request->destino;
            $unidade = Auth::user()->getUnidade();

            $sql = "SELECT  v.VEIC_placa_cavalo             as placa, 
                            ifnull(e.ESTA_foi_chamado,'N')  as chamado, 
                            ifnull(m.MOTO_nome,'')          as nome, 
                            e.ESTA_id                       as id
                    FROM    SGP_estadia e, 
                            SGP_veiculo v, 
                            SGP_motorista m, 
                            SGP_destino d
                    WHERE   e.ESTA_FK_MOTO_id = m.MOTO_id
                    AND     e.ESTA_FK_VEIC_id = v.VEIC_id
                    AND     e.ESTA_FK_DEST_id = d.DEST_id
                    AND     e.ESTA_status     = 'PA' ";
            $sql .="AND     e.ESTA_FK_UNID_id=" .$unidade. " ";
            if($destino!='')
            {
                $sql .="AND d.DEST_codigo = '" .$destino. "' ";
            }
            $sql .="ORDER BY e.ESTA_data_prev, e.ESTA_hora_prev LIMIT 100 ";


            //executa a query e guarda o resultado
            $resultado =\DB::select($sql);
            
            $dados = ['consulta'=>$resultado];
            
            return response()->json($dados,200);
        }
        catch(\Exception $ex)
        {
            return response()->json('erro ao buscar os dados da operação: '.$ex->getMessage(),500);
        }

    }

    
    public function ajaxPesquisaFilaCliente(Request $request)
    {
        try
        {
            $cliente = $request->cliente;
            $unidade = Auth::user()->getUnidade();
            $transp  = Auth::user()->getTransp();

            if($cliente=='0')
            {
                $cliente='';
            }

            $sql = "SELECT      date_format(e.ESTA_data_prev,'%d/%m/%Y')        as data,
                                e.ESTA_hora_prev                as hora,
                                v.VEIC_placa_cavalo             as placa,
                                substring(upper(ifnull(m.MOTO_nome,'')),1,20)   as motorista, 
                                substring(upper(p.PROD_descricao),1,15)         as produto,
                                substring(upper(d.DEST_descricao),1,20)         as destino,
                                e.ESTA_tipo_carga                               as tipocarga,
                                e.ESTA_id                       as id,
                                ifnull(e.ESTA_foi_chamado,'N')  as chamado
                    FROM        SGP_estadia e, 
                                SGP_veiculo v, 
                                SGP_motorista m, 
                                SGP_destino d,
                                SGP_cliente c,
                                SGP_produto p
                    WHERE       e.ESTA_FK_MOTO_id = m.MOTO_id
                    AND         e.ESTA_FK_VEIC_id = v.VEIC_id
                    AND         e.ESTA_FK_DEST_id = d.DEST_id
                    AND 	    e.ESTA_FK_PROD_id = p.PROD_id
                    AND         e.ESTA_status     = 'PA' 
                    AND         e.ESTA_bloqueio = '0' ";
            $sql .="AND         e.ESTA_FK_CLIE_id = c.CLIE_id ";
            $sql .="AND         e.ESTA_FK_UNID_id=" .$unidade. " ";
            //$sql .="AND         d.DEST_painel_tanque='1' ";
            if($transp!='')
            {
                $sql .="AND     e.ESTA_FK_TRAN_id = " .$transp. " ";
            }
            $sql .="ORDER BY    e.ESTA_data_prev, e.ESTA_hora_prev LIMIT 200";


            //executa a query e guarda o resultado
            $resultado =\DB::select($sql);
            
            $dados = ['consulta'=>$resultado];
            
            return response()->json($dados,200);
        }
        catch(\Exception $ex)
        {
            return response()->json('erro ao buscar os dados da operação: '.$ex->getMessage(),500);
        }

    }

    public function ajaxPesquisaFilaClienteGraos(Request $request)
    {
        try
        {
            //$cliente = $request->cliente;
            $unidade = Auth::user()->getUnidade();

            //if($cliente=='0')
            //{
            //    $cliente='';
            //}

            $sql = "SELECT      date_format(e.ESTA_data_prev,'%d/%m/%Y') as data,
                                e.ESTA_hora_prev                as hora,
                                v.VEIC_placa_cavalo             as placa,
                                substring(upper(ifnull(m.MOTO_nome,'')),1,20)   as motorista, 
                                substring(upper(p.PROD_descricao),1,15)         as produto,
                                substring(upper(d.DEST_descricao),1,20)         as destino,
                                e.ESTA_id                       as id,
                                ifnull(e.ESTA_foi_chamado,'N')  as chamado
                    FROM        SGP_estadia e, 
                                SGP_veiculo v, 
                                SGP_motorista m, 
                                SGP_destino d,
                                SGP_cliente c,
                                SGP_produto p
                    WHERE       e.ESTA_FK_MOTO_id = m.MOTO_id
                    AND         e.ESTA_FK_VEIC_id = v.VEIC_id
                    AND         e.ESTA_FK_DEST_id = d.DEST_id
                    AND 	    e.ESTA_FK_PROD_id = p.PROD_id
                    AND         e.ESTA_status     = 'PA' 
                    AND         e.ESTA_bloqueio = '0' ";
            $sql .="AND         e.ESTA_FK_CLIE_id = c.CLIE_id ";
            $sql .="AND         e.ESTA_FK_UNID_id=" .$unidade. " ";
            $sql .="AND         c.CLIE_painel='1' ";
            $sql .="ORDER BY    e.ESTA_data_prev, e.ESTA_hora_prev LIMIT 100";

            //executa a query e guarda o resultado
            $resultado =\DB::select($sql);
            
            $dados = ['consulta'=>$resultado];
            
            return response()->json($dados,200);
        }
        catch(\Exception $ex)
        {
            return response()->json('erro ao buscar os dados da operação: '.$ex->getMessage(),500);
        }

    }


    public function ajaxPesquisaFilaFertgrow(Request $request)
    {
        try
        {
            //$cliente = $request->cliente;
            $unidade = Auth::user()->getUnidade();


            $sql = "SELECT      date_format(e.ESTA_data_prev,'%d/%m/%Y') as data,
                                e.ESTA_hora_prev                as hora,
                                v.VEIC_placa_cavalo             as placa,
                                substring(upper(ifnull(m.MOTO_nome,'')),1,20)   as motorista, 
                                substring(upper(p.PROD_descricao),1,15)         as produto,
                                substring(upper(d.DEST_descricao),1,20)         as destino,
                                e.ESTA_id                       as id,
                                ifnull(e.ESTA_foi_chamado,'N')  as chamado
                    FROM        SGP_estadia e, 
                                SGP_veiculo v, 
                                SGP_motorista m, 
                                SGP_destino d,
                                SGP_cliente c,
                                SGP_produto p
                    WHERE       e.ESTA_FK_MOTO_id = m.MOTO_id
                    AND         e.ESTA_FK_VEIC_id = v.VEIC_id
                    AND         e.ESTA_FK_DEST_id = d.DEST_id
                    AND 	    e.ESTA_FK_PROD_id = p.PROD_id
                    AND         e.ESTA_status     = 'PA' 
                    AND         e.ESTA_FK_CLIE_id = c.CLIE_id 
                    AND         c.CLIE_painelfgw = 1 ";
            $sql .="AND         e.ESTA_FK_UNID_id=" .$unidade. " ";
            $sql .="ORDER BY    e.ESTA_data_prev, e.ESTA_hora_prev LIMIT 400";


            //executa a query e guarda o resultado
            $resultado =\DB::select($sql);
            
            $dados = ['consulta'=>$resultado];
            
            return response()->json($dados,200);
        }
        catch(\Exception $ex)
        {
            return response()->json('erro ao buscar os dados da operação: '.$ex->getMessage(),500);
        }

    }



}
