<?php

namespace App\Http\Controllers;

use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Auth;
use Illuminate\Http\Request;
use App\Sistema;
use App\Rota;

class RotaController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function indexRotas()
    {
        //verifica acesso à rota
        if(!RotaController::Acesso('adm.rota'))
        {
            return RotaController::AcessoNegado('home');
        }

        try
        {
            //recupera as rotas do sistema
            $rotas = Rota::whereHas('Sistema',function($sistema)
                    {
                        $sistema->where(Sistema::$codigo,env('APP_SISTEMA'));
                    })->get();

            //recupera as permissões às funcionalidades
            $permisEditar = RotaController::Acesso('adm.rota.salvar');
            $permisDelete = RotaController::Acesso('adm.rota.delete');


            return View('adm.rota',['rotas'=>$rotas,'permEditar'=>$permisEditar,'permDelete'=>$permisDelete]);
        }
        catch(\Exception $ex)
        {
            Redirect::route('home')->withErrors('Erro ao carregar as rotas: '. $ex->getMessage());
        }

    }

    public function salvarRota(Request $request)
    {
        if(!RotaController::Acesso($request->route()->getName())){return RotaController::AcessoNegado('adm.rota');}

        try
        {
            $rta = Rota::whereHas('Sistema',function($sistema)
                {
                    $sistema->where(Sistema::$codigo,env('APP_SISTEMA'));
                })
                ->where(function($query) use ($request)
                {
                    $query->where(Rota::$rota,$request->rota)
                            ->orWhere(Rota::$nome,$request->nome);
                })->first();

            if((empty($request->id) && !empty($rta)) || (!empty($request->id) && !empty($rta) &&  $request->id != $rta->getId()))
            {
                return Redirect::route('adm.rota')->withErrors('Já existe uma rota com este nome ou este endereço.');
            }

            $rota = Rota::findOrNew($request->id);
            $rota->setNome($request->nome);
            $rota->setRota($request->rota);
            $rota->setIcone($request->icone);
            $rota->setFkSistema(Util::getSistema()->getId());
            $rota->setMenu(!empty($request->menu));
            $rota->setFkRotaPai($request->pai);

            $rota->save();

            return Redirect::route('adm.rota');
        }
        catch(\Exception $ex)
        {
            Redirect::route('adm.rota')->withErrors('Erro ao salvar a rota: '. $ex->getMessage());
        }
    }

    public function deleteRota(Request $request)
    {
        if(!RotaController::Acesso($request->route()->getName()))
        {
            return RotaController::AcessoNegado('adm.rota');
        }

        try
        {
            $rota = Rota::find($request->id);
            $rota->delete();

            return Redirect::route('adm.rota');
        }
        catch(\Exception $ex)
        {
            Redirect::route('adm.rota')->withErrors('Erro ao excluir a rota: '. $ex->getMessage());
        }
    }

    public function ajaxRotaPai(Request $request)
    {

        try
        {
            $rotas = Rota::whereHas('Sistema',function($sistema)
                    {
                        $sistema->where(Sistema::$codigo,env('APP_SISTEMA'));
                    });

            if(!empty($request->id))
            {
                $rotas->where(Rota::$id,'!=',$request->id);
            }

            $rotas = $rotas->orderby(Rota::$nome)
                    ->get()
                    ->map(function ($item)
                    {
                        return
                        [
                            'id'=>$item->getId(),
                            'nome'=>$item->getNome()
                        ];
                    });

            return response()->json($rotas,200);
        }
        catch(\Exception $ex)
        {
            return response()->json('erro ao buscar as rotas: '.$ex->getMessage(),500);
        }
    }

    public static function GetComboRotas()
    {
        return Rota::whereHas('Sitema',function($sistema)
                {
                    $sistema->where(Sistema::$codigo,env('APP_SISTEMA'));
                })
                ->orderby(Rota::$nome)
                ->get()
                ->keyBy(Rota::$id)->map(function ($item)
                {
                    return $item->getNome();
                });
    }


    public static function Acesso($rota)
    {
        try
        {
            if(empty(Auth::user()->Classe->first()->Rotas->where(Rota::$rota,$rota)->first()))
            {
                Util::Log('acesso negado à rota: '.$rota);

                return false;
            }
            else
            {
                return true;
            }
        }
        catch(\Exception $ex)
        {
            return false;
        }
    }

    public static function AcessoNegado($redirecionar)
    {
        return Redirect::route($redirecionar)->with('alerta','privilégios insuficientes. Procure o administrador do sistema.');
    }

}
