<?php

namespace App\Http\Controllers;

use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Auth;
use Illuminate\Http\Request;
use App\Sistema;

class SistemaController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

     //############ SISTEMA ############
     public function indexSistema(Request $request)
     {
        if(!RotaController::Acesso($request->route()->getName()))
        {
            return RotaController::AcessoNegado('home');
        }

         try
         {
             $sistemas = Sistema::all();
 
             return view('adm.sistemas',['sistemas'=>$sistemas]);
         }
         catch(\Exception $ex)
         {
             return Redirect::back()->withErrors('erro ao carregar os sistemas: '.$ex->getMessage());
         }
     }

     //############ SISTEMA ############
    public function indexCadastroSistema(Request $request)
    {
    // if(!RotaController::Acesso($request->route()->getName()))
    // {
    //     return RotaController::AcessoNegado('home');
    // }

        try
        {
            return view('adm.cadastrosistema');
        }
        catch(\Exception $ex)
        {
            if(Auth::user()->Classe->first()->getCodigo() == 'ADM')
            {
                return Redirect::route('home')->withErrors('erro ao carregar os sistemas: '.$ex->getMessage());
            }
            else
            {
                return Redirect::route('home')->withErrors('erro ao carregar os sistemas!');
            }
        }
    }

    //############ SISTEMA ############
    public function indexEditarCadastroSistema($prefixo,$id,$sufixo)
    {
    // if(!RotaController::Acesso($request->route()->getName()))
    // {
    //     return RotaController::AcessoNegado('home');
    // }

        try
        {
            $sistema = Sistema::find($id);
            return view('adm.cadastrosistema',['id'=>$id,'sistema'=>$sistema]);
        }
        catch(\Exception $ex)
        {
            if(Auth::user()->Classe->first()->getCodigo() == 'ADM')
            {
                return Redirect::route('home')->withErrors('erro ao carregar os sistemas: '.$ex->getMessage());
            }
            else
            {
                return Redirect::route('home')->withErrors('erro ao carregar os sistemas!');
            }
        }
    }

     public function salvarSistema(Request $request)
    {
        if(!RotaController::Acesso($request->route()->getName()))
        {
            return RotaController::AcessoNegado('adm.sistema');
        }

        try
        {
            $sist = Sistema::where(Sistema::$codigo,$request->codigo)->first();

            if((empty($request->id) && !empty($sist)) || (!empty($request->id) && !empty($sist) && $request->id != $sist->getId()))
            {
                return Redirect::back()->withErrors('Já existe um sistema com este código.');
            }

            $sistema = Sistema::findOrNew($request->id);
            $sistema->setCodigo($request->codigo);
            $sistema->setDescricao($request->descricao);

            $sistema->save();

            if($request->id)
            {
                return Redirect::route('adm.sistema')->with('mensagem','Cadastro de sistema ' .$sistema->getDescricao(). ' editado com sucesso!');
            }
            else
            {
                return Redirect::route('adm.sistema')->with('mensagem','Cadastro de sistema ' .$sistema->getDescricao(). ' efetuado com sucesso!');
            }
        }
        catch(\Exception $ex)
        {
            if(Auth::user()->Classe->first()->getCodigo() == 'ADM')
            {
                return Redirect::back()->withErrors('erro ao salvar o sistema: '.$ex->getMessage());
            }
            else
            {
                return Redirect::back()->withErrors('erro ao salvar o sistema!');
            }
        }        
    }

    public function deleteSistema(Request $request)
    {
        if(!RotaController::Acesso($request->route()->getName()))
        {
            return RotaController::AcessoNegado('adm.sistema');
        }

        try
        {
            if(empty($request->id))
            {
                return Redirect::back()->withErrors('Código do sistema vazio.');
            }

            $sistema = Sistema::find($request->id);
            $descricao = $sistema->getDescricao();
            $sistema->delete();

            return Redirect::route('adm.sistema')->with('exclusao', $descricao. ' excluído com sucesso!');
        }
        catch(\Exception $ex)
        {
            if(Auth::user()->Classe->first()->getCodigo() == 'ADM')
            {
                return Redirect::back()->withErrors('erro ao excluir o sistema: '.$ex->getMessage());
            }
            else
            {
                return Redirect::back()->withErrors('erro ao excluir o sistema!');
            }
        }
        
    }
 
}
