<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Auth;
use App\User;
use Hash;

class UsuarioController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function indexUsuario(Request $request)
    {
        if(!RotaController::Acesso($request->route()->getName())){return RotaController::AcessoNegado('home');}

        try
        {
            $usuarios = User::all();
            $classes = ClasseController::GetComboClasse();

            return View('adm.usuarios',['usuarios'=>$usuarios,'classes'=>$classes]);
        }
        catch(\Exception $ex)
        {
            return Redirect::route('adm.usuario')->withErrors('erro ao carregar os usuários: '.$ex->getMessage());
        }
    }

    public function indexTrocaSenha(Request $request)
    {
        if(!RotaController::Acesso($request->route()->getName())){return RotaController::AcessoNegado('home');}

        try
        {
            $usuarios = User::all();
            //$classes = ClasseController::GetComboClasse();

            return View('adm.trocasenha',['usuarios'=>$usuarios]);
        }
        catch(\Exception $ex)
        {
            return Redirect::route('adm.trocasenha')->withErrors('erro ao carregar a troca de senha: '.$ex->getMessage());
        }
    }

    public function ajaxSalvarUsuario(Request $request)
    {
        //if(!RotaController::Acesso($request->route()->getName())){return RotaController::AcessoNegado('adm.usuario');}
        
        try
        {
            //$user = User::where(User::$cpf,$cpf)->first();

            //if((empty($request->id) && !empty($user)) || (!empty($request->id) && !empty($user) && $user->getId() != $request->id))
            //{
            //    return Redirect::route('adm.usuario')->withErrors('Já existe um usuário cadastrado com o CPF informado.');
            //}

            $id         = $request->id;
            $login      = $request->login;
            $nome       = strtoupper($request->nome);
            $email      = strtolower($request->email);
            $celular    = Util::LimpaCelular($request->celular);
            $ativo      = $request->ativo;
            $cliente    = $request->cliente;
            $transp     = $request->transp;
            $destino    = $request->destino;
            $unidade    = Auth::user()->getUnidade();
            $cancelar   = $request->cancelar;
            $bloquear   = $request->bloquear;
            $ocorrencia = $request->ocorrencia;
            $prioridade = $request->prioridade;
            $aprovador  = $request->aprovador;
            $visto      = $request->visto;
            $texto      = $request->texto;
            
            $usuario = User::findOrNew($id);
            $usuario->setNome($nome);
            $usuario->setEmail($email);
            $usuario->setCelular($celular);
            $usuario->setLogin($login);
            $usuario->setCliente($cliente);
            $usuario->setTransp($transp);
            $usuario->setDestino($destino);
            $usuario->setAtivo(!empty(($ativo)));
            $usuario->setCancelar(!empty(($cancelar)));
            $usuario->setBloquear(!empty(($bloquear)));
            $usuario->setOcorrencia(!empty(($ocorrencia)));
            $usuario->setPrioridade(!empty(($prioridade)));
            $usuario->setAprovador(!empty(($aprovador)));
            $usuario->setVisto(!empty(($visto)));
            
            $usuario->setUnidade($unidade);
            if(empty($request->id) || (!empty($request->id) && !empty($request->senha)))
            {
                $usuario->setSenha(Util::Criptografia($request->senha));
            }
            $usuario->save();

            //seta a permissão do usuário
            ClasseController::PermissaoUsuario($usuario,$request->classe);

            //grava na log
            Util::Log($texto);

            if($request->id)
            {
                return Redirect::route('adm.usuario')->with('mensagem','Cadastro de usuário ' .$usuario->getNome(). ' editado com sucesso!');
            }
            else
            {
                return Redirect::route('adm.usuario')->with('mensagem','Cadastro de usuário ' .$usuario->getNome(). ' efetuado com sucesso!');
            }
        }
        catch(\Exception $ex)
        {
            return Redirect::route('adm.usuario')->withErrors('erro ao salvar o usuário: '.$ex->getMessage());
        }
    }

    public function deleteUsuario(Request $request)
    {
        if(!RotaController::Acesso($request->route()->getName())){return RotaController::AcessoNegado('adm.usuario');}
        
        try
        {
            $usuario = User::find($request->id);
            $usuario->delete();

            return Redirect::route('adm.usuario');
        }
        catch(\Exception $ex)
        {
            return Redirect::back()->withErrors('erro ao excluir o usuário: '.$ex->getMessage());
        }
    }

    public function ajaxListaUsuario(Request $request)
    {
        try
        {
            $unidade    = Auth::user()->getUnidade();

            //Seleciona dados do usuario
            $sql = "SELECT USUA_id as id, upper(USUA_nome) as nome
                    FROM    TBG_usuario ";
            $sql .= "WHERE USUA_FK_UNID_id=" .$unidade. " ";
            $sql .= "ORDER BY USUA_nome";
                                                     
            //executa a query e guarda o resultado
            $resultado =\DB::select($sql);
                            
            $dados = ['consulta'=>$resultado];
            //$consulta = $resultado;
            
            return response()->json($dados,200);
        }
        catch(\Exception $ex)
        {
            return response()->json('erro ao buscar os dados do usuário: '.$ex->getMessage(),500);
        }
    }

    public function salvarSenha(Request $request)
    {
        //if(!RotaController::Acesso($request->route()->getName())){return RotaController::AcessoNegado('adm.usuario');}
        
        try
        {
           
            $id = $request->hdusuario;      //pega o ID do campo hidden na modal

            $usuario = User::findOrNew($id);
            $usuario->setSenha(Util::Criptografia($request->senha));
            
            $usuario->save();

            return Redirect::route('adm.trocasenha');
        }
        catch(\Exception $ex)
        {
            return Redirect::route('adm.trocasenha')->withErrors('erro ao salvar a senha: '.$ex->getMessage());
        }
    }

    public function indexConsultaLog(Request $request)
    {
        if(!RotaController::Acesso($request->route()->getName())){return RotaController::AcessoNegado('home');}

        try
        {
          
            return View('adm.consultalog');
        }
        catch(\Exception $ex)
        {
            return Redirect::route('adm.consultalog')->withErrors('erro ao carregar consulta logs: '.$ex->getMessage());
        }
    }

    public function ajaxPesquisaLog(Request $request)
    {
        try
        {
            $usuario    = $request->usuario;
            $mes        = $request->mes;
            $ano        = $request->ano;
            $unidade    = Auth::user()->getUnidade();
            $palavra    = $request->palavra;

            $sql="SELECT    date_format(l.LOG_data, '%d/%m/%Y %H:%i') as datal, 
                            upper(u.USUA_nome) as nome, upper(u.USUA_login) as login, upper(l.LOG_descricao) as descricao 
                    FROM    TBG_log l, TBG_usuario u 
                    WHERE   l.LOG_FK_USUA_id = u.USUA_id ";
            $sql .="AND     l.LOG_FK_UNID_id = " .$unidade. " ";
            if(!empty($ano))
            {
                $sql .="AND year(l.LOG_data) = " .$ano. " ";
                if(!empty($mes))
                {
                    $sql .= "AND month(l.LOG_data) = " .$mes. " ";
                }
            } 
            if(!empty($usuario))
            {
                $sql .="AND u.USUA_id = " .$usuario. " ";
            }
            if($palavra!='')
            {
                $sql .="AND l.LOG_descricao LIKE '%" .$palavra. "%' ";
            }
            $sql .="ORDER BY l.LOG_data DESC";

            //executa a query e guarda o resultado
            $consulta =\DB::select($sql);
            
            $dados = ['consulta'=>$consulta];

            return response()->json($dados,200);
        }
        catch(\Exception $ex)
        {
            //return response()->json('erro ao buscar os veículos da operação: '.$ex->getMessage(),500);
            return response()->json($ex->getMessage(),200);
        }
    }


    public function ajaxPesquisaClasse(Request $request)
    {
        try
        {
            $usuario = $request->usuario;

            //Seleciona dados da operação
            $sql = "SELECT c.CLA_codigo as codigo
                    FROM TBG_permissao p, TBG_classe c
                    WHERE p.PERM_FK_CLA_id = c.CLA_id
                    AND p.PERM_FK_USUA_id= " .$usuario. " ";
            $sql .="AND c.CLA_FK_SIST_id=1";
                                                     
            //executa a query e guarda o resultado
            $resultado =\DB::select($sql);
            
            $dados = ['consulta'=>$resultado];
            
            return response()->json($dados,200);
        

        }
        catch(\Exception $ex)
        {
            return response()->json('erro ao buscar os dados: '.$ex->getMessage(),500);
        }
        
    }

    public function ajaxPesquisaUsuario(Request $request)
    {
        try
        {
            $status  =$request->status;
            $cliente  =$request->cliente;
            $palavra  =$request->palavra;
            $unidade = Auth::user()->getUnidade();

            if($cliente=='' || $cliente==null)
            {
                $cliente='0';
            }
                        
            //Seleciona dados da operação
            $sql = "SELECT  u.USUA_id as id, 
                            upper(USUA_nome) as nome, 
                            upper(u.USUA_login) as login, 
                            ifnull(u.USUA_email,'') as email, 
                            ifnull(u.USUA_celular,'') as celular, 
                            u.USUA_ativo as ativo,
                            u.USUA_aprovador        as aprovador,
                            u.USUA_visto            as visto,
                            ifnull(u.USUA_cod_cliente,'0') as cliente, 
                            ifnull(u.USUA_cod_transp,'0') as transportador,
                            ifnull(u.USUA_cod_destino,'0') as destino,
                            ifnull(u.USUA_bloqueio,'0') as bloqueio,
                            ifnull(u.USUA_ocorrencia,'0') as ocorrencia,
                            ifnull(u.USUA_cancelar,'0') as cancelar,
                            ifnull(u.USUA_prioridade,'0') as prioridade
                    FROM    TBG_usuario u 
                    WHERE   u.USUA_id > 0 
                    AND     u.USUA_id IN (
                                SELECT PERM_FK_USUA_id FROM TBG_permissao , TBG_classe
                                WHERE PERM_FK_CLA_id=CLA_id
                                AND CLA_codigo NOT IN ('ADM','MAST')) ";
                    $sql .= "AND u.USUA_FK_UNID_id=" .$unidade. " ";
                    if($status!='')
                    {
                        $sql .="AND u.USUA_ativo=" .$status. " ";
                    }
                    if($cliente!='0')
                    {
                        $sql .="AND u.USUA_cod_cliente='" .$cliente. "' ";
                    }
                    if($palavra!='')
                    {
                        $sql .="AND (u.USUA_login LIKE '%" .$palavra. "%' ";
                        $sql .="OR   u.USUA_nome LIKE '%" .$palavra. "%' ";
                        $sql .="OR   u.USUA_email LIKE '%" .$palavra. "%' ";
                        $sql .="OR   u.USUA_celular LIKE '%" .$palavra. "%') ";
                    }
                    $sql .="ORDER BY u.USUA_nome";
                                         
             //executa a query e guarda o resultado
             $consulta =\DB::select($sql);
            
             $dados = ['consulta'=>$consulta];
 
             return response()->json($dados,200);
        }
        catch(\Exception $ex)
        {
            return response()->json('erro ao buscar os dados da operação: '.$ex->getMessage(),500);
        }
        
    }

    public function ajaxPesquisaClasseUsuario(Request $request)
    {
        try
        {
            $usuario=$request->usuario;
                        
            //Seleciona dados da operação
            $sql = "SELECT  p.PERM_FK_CLA_id as classe
                    FROM    TBG_permissao p, TBG_classe c
                    WHERE   p.PERM_FK_CLA_id = c.CLA_id ";
            $sql .="AND     p.PERM_FK_USUA_id=" .$usuario. " ";
            $sql .="AND     c.CLA_FK_SIST_id=1 ";
                                         
            //executa a query e guarda o resultado
            $resultado =\DB::select($sql);
            
            $dados = ['consulta'=>$resultado];
            
            return response()->json($dados,200);
        }
        catch(\Exception $ex)
        {
            return response()->json('erro ao buscar os dados da operação: '.$ex->getMessage(),500);
        }
        
    }

    public function ajaxPesquisaUsuarioLista(Request $request)
    {
        try
        {
            $unidade = Auth::user()->getUnidade();

            //Seleciona dados da operação
            $sql = "SELECT      u.USUA_id as id, upper(u.USUA_nome) as nome , upper(u.USUA_login) as login
                    FROM        TBG_usuario u ";
            $sql .= "WHERE       USUA_FK_UNID_id=" .$unidade. " ";
            $sql .= "ORDER BY    USUA_nome";
                                                     
            //executa a query e guarda o resultado
            $resultado =\DB::select($sql);
            
            $dados = ['consulta'=>$resultado];
            
            return response()->json($dados,200);
        

        }
        catch(\Exception $ex)
        {
            return response()->json('erro ao buscar os dados: '.$ex->getMessage(),500);
        }
        
    }


    public function ajaxListaOperadorCaixa(Request $request)
    {
        try
        {
            $unidade = Auth::user()->getUnidade();

            //Seleciona dados da operação
            $sql = "SELECT  USUA_id as id, USUA_nome as nome 
                    FROM    TBG_usuario 
                    WHERE   USUA_id IN (SELECT DISTINCT x.CAIXA_FK_USUA_id 
                    FROM    SGP_caixa x ";
            $sql .="WHERE x.CAIXA_FK_UNID_id=" .$unidade. ") "; 
            $sql .="AND     USUA_ativo=1 ";
            $sql .="AND     USUA_FK_UNID_id=" .$unidade. " ";
            $sql .="ORDER BY USUA_nome";
                                                     
            //executa a query e guarda o resultado
            $resultado =\DB::select($sql);
            
            $dados = ['consulta'=>$resultado];
            
            return response()->json($dados,200);
        

        }
        catch(\Exception $ex)
        {
            return response()->json('erro ao buscar os dados: '.$ex->getMessage(),500);
        }
        
    }

    public function ajaxListaUnidade(Request $request)
    {
        try
        {
            $unidade = Auth::user()->getUnidade();

            //Seleciona dados da operação
            $sql = "SELECT u.UNID_id as id, u.UNID_nome as nome FROM TBG_unidade u WHERE u.UNID_ativo=1 ORDER BY u.UNID_nome";
                                                     
            //executa a query e guarda o resultado
            $resultado =\DB::select($sql);
            
            $dados = ['consulta'=>$resultado];
            
            return response()->json($dados,200);
        

        }
        catch(\Exception $ex)
        {
            return response()->json('erro ao buscar os dados: '.$ex->getMessage(),500);
        }
        
    }

        
    public function ajaxListaSetor(Request $request)
    {
        try
        {
            $unidade = $request->unidade;
            
            //Seleciona dados da operação
            $sql = "SELECT  s.SETOR_id as id, s.SETOR_descricao as nome 
                    FROM    TBG_setor s WHERE s.SETOR_FK_UNID_id= " .$unidade. " ";
            $sql .= "ORDER BY s.SETOR_descricao";
                                                     
            //executa a query e guarda o resultado
            $resultado =\DB::select($sql);
            
            $dados = ['consulta'=>$resultado];
            
            return response()->json($dados,200);
        

        }
        catch(\Exception $ex)
        {
            return response()->json('erro ao buscar os dados: '.$ex->getMessage(),500);
        }
        
    }

    public function ajaxPesquisaUnidadeUsuarioLogado(Request $request)
    {
        try
        {
            $unidade = Auth::user()->getUnidade();
            
            //executa a query e guarda o resultado
            $resultado =$unidade;
            
            $dados = ['consulta'=>$resultado];
            
            return response()->json($dados,200);
        

        }
        catch(\Exception $ex)
        {
            return response()->json('erro ao buscar os dados: '.$ex->getMessage(),500);
        }
        
    }

    public function ajaxPesquisaUsuarioByLogin(Request $request)
    {
        try
        {
            $login = $request->login;
            
            //Seleciona dados da operação
            $sql = "SELECT COUNT(*) as qtde FROM TBG_usuario WHERE USUA_login='" .$login. "' ";
                                                    
            //executa a query e guarda o resultado
            $resultado =\DB::select($sql);
            
            $dados = ['consulta'=>$resultado];
            
            return response()->json($dados,200);
        

        }
        catch(\Exception $ex)
        {
            return response()->json('erro ao buscar os dados: '.$ex->getMessage(),500);
        }
        
    }

    public function ajaxListaUsuarioDestino(Request $request)
    {
        try
        {
            $unidade = Auth::user()->getUnidade();

            //Seleciona dados da operação
            $sql = "SELECT  USUA_id as id, 
                            USUA_nome as nome 
                    FROM    TBG_usuario 
                    WHERE   USUA_cod_destino=1 
                    AND     USUA_ativo=1 ";
            $sql .="AND     USUA_FK_UNID_id=" .$unidade. " ";
            $sql .="ORDER BY USUA_nome";
                                                     
            //executa a query e guarda o resultado
            $resultado =\DB::select($sql);
            
            $dados = ['consulta'=>$resultado];
            
            return response()->json($dados,200);
        

        }
        catch(\Exception $ex)
        {
            return response()->json('erro ao buscar os dados: '.$ex->getMessage(),500);
        }
        
    }

   
}
