<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Sistema;
use Carbon\Carbon;
use Illuminate\Support\Facades\Auth;
use App\Log;
use App\Parametro;
use Hash;

class Util extends Controller
{
    /**
     * Salva o arquivo no servidor e retorna o caminho do arquivo
     */
    public static function SalvarArquivo($arquivo,$pasta,$nome)
    {
        $nameFile = null;
        if(empty($nome))
        {
            $name = md5(uniqid(rand(), true));
            $extension = $arquivo->extension();
            $nameFile= "{$name}.{$extension}";
        }
        else
        {
            $nameFile = $nome;
        }

        return $arquivo->storeAs($pasta, $nameFile);
    }

    /**
     * Busca no BD o sistema em questão
     */
    public static function getSistema()
    {
        return Sistema::where(Sistema::$codigo,env('APP_SISTEMA'))->first();
    }

     /**
     * Retorna o valor com a criptografia do sistema
     */
    public static function Criptografia($valor)
    {
        return Hash::make($valor);
    }

    /**
     * Retira os '.' e '-' do CPF
     */
    public static function LimpaCpf($cpf)
    {
        return str_replace('/','',str_replace('-','',str_replace('.','',$cpf)));
    }

    /**
     * Retira os '(', ')' e '-' do Celular
     */
    public static function LimpaCelular($celular)
    {
        return str_replace('(','',str_replace(')','',str_replace(' ','',str_replace('-','',str_replace('.','',$celular)))));
    }

    /**
     * Gera o registro na tabela de log do sistema
     */
    public static function Log($descricao)
    {
        $data = Carbon::now()->timezone('America/Fortaleza');
        $unidade =  Auth::user()->getUnidade();

        $log = New Log;
        $log->setDescricao($descricao);
        $log->setData($data);
        $log->setFkSistema(Util::getSistema()->getId());
        $log->setFkUsuario(Auth::user()->getId());
        $log->setUnidade($unidade);
        $log->save();
    }

    public static function GetParametro($codigo)
    {
        $parametro = Parametro::where(Parametro::$codigo,$codigo)->first();
        return (empty($parametro) ? null : $parametro->getValor());
    }

    public static function GetNomeUnidade($codigo)    
    {
        $unidade = Unidade::where(Unidade::$id,$codigo)->first();
        return (empty($unidade) ? null : $unidade->getNome());
    }

    public static function RemoveCaracter($palavra)
    {
        return str_replace('ç','c',$palavra);
    }

    public static function VerificaDuplicidade($id_request,$consulta)
    {
        return ((empty($id_request) && !empty($consulta)) || (!empty($id_request) && !empty($consulta) && $id_request != $consulta->getId()));
    }

    /**
     * Retira os '.' e '-' do CPF
     */
    public static function LimpaData($data)
    {
        return str_replace('/','',str_replace('/','',str_replace('/','',$data)));
    }

    public static function StringAleatoria()
    {
        return md5(uniqid(rand(), true));
    }

    public static function Ponto($numero)
    {
        return str_replace(',','.',$numero);
    }
    
}
