@extends('layouts.app')

@section('titulo')
    <i class="fas fa-route"></i> Rotas
@endsection

@section('scripts')
    <script src="{{{ URL::asset('js/treetable/treeTable.js') }}}"></script>
    <script src="{{{ URL::asset('js/views/adm/rota.js') }}}"></script>
@endsection

@section('pagina')

<div class="content-wrapper">
    <div class="container-fluid mt-2">
        <div class="card rounded text-left" style="background-color:#fff; color:#056367; border-radius: 10px 10px 10px 10px;">
            <div class="card-body">
                @if($permEditar)
                    <div class="row" >
                        <div class="col text-right">
                            <button id="btnNovaRota" type="button" class="btn btn-primary btn-redondo" aria-label="Left Align" >
                                <i class="fas fa-plus-circle"></i> Nova Rota
                            </button>
                        </div>
                    </div>
                    <br/>
                @endif
            </div>
        </div>

        <div class="card mt-2" style="background-color:#fff; color:#056367; border-radius: 10px 10px 10px 10px;">
            <div class="card-body">
                <div class="row" >
                    <div class="col panel panel-primary table-responsive">
                        <table id="tbRotas" class="table table-striped table-bordered text-left ">
                            <thead  style="background-color:#333333; color: #ccc; font-weight: bold;">
                                <tr>
                                    <th>Nome</th>
                                    <th>Rota</th>
                                    <th>Rota Pai</th>
                                    <th>Menu</th>
                                    <th>Ícone</th>

                                    @if($permEditar || $permDelete)
                                        <th>Ações</th>
                                    @endif

                                </tr>
                            </thead>
                            <tbody>

                                @foreach($rotas as $rota)
                                    <tr data-tt-id="{{$rota->getId()}}" data-tt-parent-id="{{(empty($rota->RotaPai) ? '' : $rota->RotaPai->getId())}}">
                                        <td id="{{$rota->getId()}}_nome">{{$rota->getNome()}}</td>
                                        <td id="{{$rota->getId()}}_rota">{{$rota->getRota()}}</td>
                                        <td id="{{$rota->getId()}}_rota_pai" data="{{(empty($rota->RotaPai) ? '' : $rota->RotaPai->getId())}}">
                                            {{(empty($rota->RotaPai) ? '' : $rota->RotaPai->getNome())}}
                                        </td>
                                        <td id="{{$rota->getId()}}_menu" data="{{$rota->isMenu()}}">

                                            @if($rota->isMenu())
                                                <span class="badge badge-success estilobag">SIM</span>
                                            @else
                                                <span class="badge badge-danger estilobag">NÃO</span>
                                            @endif

                                        </td>
                                        <td id="{{$rota->getId()}}_icone" data="{{$rota->getIcone()}}">
                                            <i class="{{$rota->getIcone()}} fa-2x"></i>
                                        </td>

                                        @if($permEditar || $permDelete)
                                            <td>
                                                @if($permEditar)
                                                    <span name="editBtn" class="fas fa-edit fa-2x cursor-pointer text-success" data="{{$rota->getId()}}" title="Editar"></span>
                                                @endif

                                                @if($permDelete)
                                                    <span name="delBtn" class="fas fa-trash-alt fa-2x cursor-pointer text-danger" data="{{$rota->getId()}}" title="Excluir"></span>
                                                @endif
                                            </td>
                                        @endif
                                    </tr>
                                @endforeach

                            </tbody>
                        </table>

                    </div>
                </div>
            </div>
        </div>
    </div>

    @if($permEditar)

        <!-- Inclui formulário modal -->
        @include('partials._modal_form',
        [
            'idModal'=>'dlgRota',
            'titulo'=> 'Nova Rota',
            'icone'=>'fa-route',
            'rota' => 'adm.rota.salvar',
            'campos'=>
            [
                [
                    'tipo'=>'array',
                    'campos'=>
                    [
                        [
                            'largura'=>'5',
                            'id' =>'cbMenu',
                            'label'=>'Menu',
                            'nome'=>'menu',
                            'tipo'=>'slider'
                        ]
                    ]
                   
                ],
                [
                    'id' =>'txtNome',
                    'label'=>'Nome',
                    'nome'=>'nome',
                    'tamanho'=>'50',
                    'tipo'=>'txt',
                    'required'=> true,
                    'autofocus'=> true,
                    'autocomplete'=>'off'
                ],
                [
                    'id' =>'txtRota',
                    'label'=>'Rota',
                    'nome'=>'rota',
                    'tamanho'=>'50',
                    'tipo'=>'txt',
                    'required'=> true,
                    'autocomplete'=>'off'
                ],
                [
                    'tipo'=>'array',
                    'campos'=>
                    [
                        [
                            'largura'=>'10',
                            'id' =>'txtIcone',
                            'label'=>'icone',
                            'nome'=>'icone',
                            'tamanho'=>'50',
                            'tipo'=>'txt'
                        ],
                        [
                            'largura'=>'2',
                            'id' =>'icnRota',
                            'label'=>'',
                            'style'=>'font-size:xx-large;padding-top:32px;',
                            'tipo'=>'icone'
                        ]
                    ]
                ],
                [
                    'id' =>'cbPai',
                    'label'=>'Rota pai',
                    'nome'=>'pai',
                    'tipo'=>'combo',
                    'opcoes'=>[]
                ]
            ]
        ])
    @endif

    @if($permDelete)
        @include('partials._modal_delete',
        [
            'rota'=>'adm.rota.delete',
            'titulo'=>'Confirma Exclusão',
            'mensagem_delete'=>'Tem certeza que deseja excluir a rota'
        ])
    @endif

@endsection
